import axios, { CanceledError } from 'axios'
import { showToast } from 'vant'

// 创建一个 axios 实例
const service = axios.create({
  baseURL: "", // 所有的请求地址前缀部分
  timeout: 60000, // 请求超时时间毫秒
  headers: {
    // 设置后端需要的传参类型
    'Content-Type': 'application/json'
  }
})

// 添加请求拦截器
service.interceptors.request.use(
  (config) => {
    return config
  },
  (error) => {
    // 对请求错误做些什么
    showToast('网络请求失败')
    return Promise.reject(error)
  }
)

// 添加响应拦截器
service.interceptors.response.use(
  (response) => {
    const res = response.data
    // 对响应错误做点什么
    if (res.code !== 200) {
        showToast(res.msg)
    }
    return res
  },
  (error) => {
    // 对响应错误做点什么
    if (error instanceof CanceledError) {
      return Promise.reject(error)
    }
    showToast(error.response?.data?.message || error.message)
    return Promise.reject(error)
  }
)

export default service